import pytest
import unittest

requests = pytest.importorskip("requests")

from PyFoam.Infrastructure.Blink1 import Blink1
